library(qiime2R)
library(metagMisc)
library(phyloseq)

### Test with own data ### 

#Import data to phyloseq
test <- qza_to_phyloseq(
  features="table.qza",
  taxonomy="taxonomy.qza",
  metadata = "metadata.tsv",
  tree = "rooted-tree.qza")

#Filter low abundant ASVs (This works with metagMisc version 0.0.4)
phyloseq_filter_prevalence(test, prev.trh = 0.05, abund.trh = 10, threshold_condition = "OR")

#OUTPUT: ERROR MESSAGE
#phyloseq_filter_prevalence(test, prev.trh = 0.05, abund.trh = 10, threshold_condition = "OR")
#Error in validObject(.Object) : invalid class “otu_table” object: 
#  OTU abundance data must have non-zero dimensions.


### Test with GlobalPatterns ###
#Remaining number of taxa is way lower than it should be. This only happens with metagMisc version 0.5.0, but not with version 0.0.4
data("GlobalPatterns")

#Filter low abundant ASVs
GlobalPatterns  # 19216 taxa

#OUTPUT:
# phyloseq-class experiment-level object
# otu_table()   OTU Table:         [ 19216 taxa and 26 samples ]
# sample_data() Sample Data:       [ 26 samples by 7 sample variables ]
# tax_table()   Taxonomy Table:    [ 19216 taxa by 7 taxonomic ranks ]
# phy_tree()    Phylogenetic Tree: [ 19216 tips and 19215 internal nodes ]

# OTUs that are found in at least 5% of samples
phyloseq_filter_prevalence(GlobalPatterns, prev.trh = 0.05, abund.trh = NULL)  # 15389 taxa

#OUTPUT:
# phyloseq-class experiment-level object
# otu_table()   OTU Table:         [ 668 taxa and 26 samples ]
# sample_data() Sample Data:       [ 26 samples by 7 sample variables ]
# tax_table()   Taxonomy Table:    [ 668 taxa by 7 taxonomic ranks ]
# phy_tree()    Phylogenetic Tree: [ 668 tips and 667 internal nodes ]

# The same, but if total OTU abundance is >= 10 reads it'll be preserved too
phyloseq_filter_prevalence(GlobalPatterns, prev.trh = 0.05, abund.trh = 10, threshold_condition = "OR")  # 15639 taxa

#OUTPUT:
# phyloseq-class experiment-level object
# otu_table()   OTU Table:         [ 677 taxa and 26 samples ]
# sample_data() Sample Data:       [ 26 samples by 7 sample variables ]
# tax_table()   Taxonomy Table:    [ 677 taxa by 7 taxonomic ranks ]
# phy_tree()    Phylogenetic Tree: [ 677 tips and 676 internal nodes ]

# Include only taxa with more than 10 reads (on average) in at least 10% samples
phyloseq_filter_prevalence(GlobalPatterns, prev.trh = 0.1, abund.trh = 10, abund.type = "mean", threshold_condition = "AND")  # 4250 taxa

#OUTPUT:
# phyloseq-class experiment-level object
# otu_table()   OTU Table:         [ 213 taxa and 26 samples ]
# sample_data() Sample Data:       [ 26 samples by 7 sample variables ]
# tax_table()   Taxonomy Table:    [ 213 taxa by 7 taxonomic ranks ]
# phy_tree()    Phylogenetic Tree: [ 213 tips and 212 internal nodes ]


